==> request-tracker4_4.4.7+dfsg.orig-third-party-source.tar.gz: rt-4.4.7/devel/third-party/ckeditor-src/plugins/link/lang/uk.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'uk', {
	acccessKey: 'Гаряча клавіша',
	advanced: 'Додаткове',
	advisoryContentType: 'Тип вмісту',
	advisoryTitle: 'Заголовок',
	anchor: {
		toolbar: 'Вставити/Редагувати якір',
		menu: 'Властивості якоря',
		title: 'Властивості якоря',
		name: 'Ім\'я якоря',
		errorName: 'Будь ласка, вкажіть ім\'я якоря',
		remove: 'Прибрати якір'
	},
	anchorId: 'За ідентифікатором елементу',
	anchorName: 'За ім\'ям елементу',
	charset: 'Кодування',
	cssClasses: 'Клас CSS',
	emailAddress: 'Адреса ел. пошти',
	emailBody: 'Тіло повідомлення',
	emailSubject: 'Тема листа',
	id: 'Ідентифікатор',
	info: 'Інформація посилання',
	langCode: 'Код мови',
	langDir: 'Напрямок мови',
	langDirLTR: 'Зліва направо (LTR)',
	langDirRTL: 'Справа наліво (RTL)',
	menu: 'Вставити посилання',
	name: 'Ім\'я',
	noAnchors: '(В цьому документі немає якорів)',
	noEmail: 'Будь ласка, вкажіть адрес ел. пошти',
	noUrl: 'Будь ласка, вкажіть URL посилання',
	other: '<інший>',
	popupDependent: 'Залежний (Netscape)',
	popupFeatures: 'Властивості випливаючого вікна',
	popupFullScreen: 'Повний екран (IE)',
	popupLeft: 'Позиція зліва',
	popupLocationBar: 'Панель локації',
	popupMenuBar: 'Панель меню',
	popupResizable: 'Масштабоване',
	popupScrollBars: 'Стрічки прокрутки',
	popupStatusBar: 'Рядок статусу',
	popupToolbar: 'Панель інструментів',
	popupTop: 'Позиція зверху',
	rel: 'Зв\'язок',
	selectAnchor: 'Оберіть якір',
	styles: 'Стиль CSS',
	tabIndex: 'Послідовність переходу',
	target: 'Ціль',
	targetFrame: '<фрейм>',
	targetFrameName: 'Ім\'я цільового фрейму',
	targetPopup: '<випливаюче вікно>',
	targetPopupName: 'Ім\'я випливаючого вікна',
	title: 'Посилання',
	toAnchor: 'Якір на цю сторінку',
	toEmail: 'Ел. пошта',
	toUrl: 'URL',
	toolbar: 'Вставити/Редагувати посилання',
	type: 'Тип посилання',
	unlink: 'Видалити посилання',
	upload: 'Надіслати'
} );

==> request-tracker5_5.0.3+dfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/link/lang/uk.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'uk', {
	acccessKey: 'Гаряча клавіша',
	advanced: 'Додаткове',
	advisoryContentType: 'Тип вмісту',
	advisoryTitle: 'Заголовок',
	anchor: {
		toolbar: 'Вставити/Редагувати якір',
		menu: 'Властивості якоря',
		title: 'Властивості якоря',
		name: 'Ім\'я якоря',
		errorName: 'Будь ласка, вкажіть ім\'я якоря',
		remove: 'Прибрати якір'
	},
	anchorId: 'За ідентифікатором елементу',
	anchorName: 'За ім\'ям елементу',
	charset: 'Кодування',
	cssClasses: 'Клас CSS',
	download: 'Завантажити як файл',
	displayText: 'Відображуваний текст',
	emailAddress: 'Адреса ел. пошти',
	emailBody: 'Тіло повідомлення',
	emailSubject: 'Тема листа',
	id: 'Ідентифікатор',
	info: 'Інформація посилання',
	langCode: 'Код мови',
	langDir: 'Напрямок мови',
	langDirLTR: 'Зліва направо (LTR)',
	langDirRTL: 'Справа наліво (RTL)',
	menu: 'Вставити посилання',
	name: 'Ім\'я',
	noAnchors: '(В цьому документі немає якорів)',
	noEmail: 'Будь ласка, вкажіть адрес ел. пошти',
	noUrl: 'Будь ласка, вкажіть URL посилання',
	noTel: 'Будь ласка, введіть номер телефону',
	other: '<інший>',
	phoneNumber: 'Номер телефону',
	popupDependent: 'Залежний (Netscape)',
	popupFeatures: 'Властивості випливаючого вікна',
	popupFullScreen: 'Повний екран (IE)',
	popupLeft: 'Позиція зліва',
	popupLocationBar: 'Панель локації',
	popupMenuBar: 'Панель меню',
	popupResizable: 'Масштабоване',
	popupScrollBars: 'Стрічки прокрутки',
	popupStatusBar: 'Рядок статусу',
	popupToolbar: 'Панель інструментів',
	popupTop: 'Позиція зверху',
	rel: 'Зв\'язок',
	selectAnchor: 'Оберіть якір',
	styles: 'Стиль CSS',
	tabIndex: 'Послідовність переходу',
	target: 'Ціль',
	targetFrame: '<фрейм>',
	targetFrameName: 'Ім\'я цільового фрейму',
	targetPopup: '<випливаюче вікно>',
	targetPopupName: 'Ім\'я випливаючого вікна',
	title: 'Посилання',
	toAnchor: 'Якір на цю сторінку',
	toEmail: 'Ел. пошта',
	toUrl: 'URL',
	toPhone: 'Телефон',
	toolbar: 'Вставити/Редагувати посилання',
	type: 'Тип посилання',
	unlink: 'Видалити посилання',
	upload: 'Надіслати'
} );
